#!/usr/bin/env python3

from gi.repository import Gtk
import xml.etree.ElementTree as ET
import datetime

class calendarApp:
        
    def __init__(self):
        self.gladefile = "calendar.glade"
        self.datafile = "calendar.xml"
        self.builder = Gtk.Builder()
        self.builder.add_from_file(self.gladefile)
        
        handlers = {"onDeleteWindow":Gtk.main_quit,
            "onButtonClick":self.saveAppt,
            "onDaySelect":self.checkAppt,
            "onPageChange":self.markDays}
        
        self.builder.connect_signals(handlers)
        self.calendar = self.builder.get_object("calendar1")
        self.textview = self.builder.get_object("textview1")
        self.buffer = self.textview.get_buffer()
        self.window = self.builder.get_object("window1")
        
        self.window.show()
        self.loadFile()
        today = datetime.datetime.now().date()
        self.calendar.select_day(today.day)
        self.calendar.select_month(today.month - 1,today.year)
        self.markDays()
        self.checkAppt()
    
    def loadFile(self):
        try:
            self.tree = ET.parse(self.datafile)
            self.root = self.tree.getroot()
        except:
            self.root = ET.Element('calendar')
            self.tree = ET.ElementTree(self.root)
            
    def dateObj2Tuple(self,dateObj):
        return (int(dateObj[0].text),int(dateObj[1].text),int(dateObj[2].text))
        
    def markDays(self, *args):
        self.calendar.clear_marks()
        calDate = self.calendar.get_date()
        for j in self.root.iter('date'):
            date = self.dateObj2Tuple(j)
            if calDate[0] == date[0] and calDate[1] == date[1]:
                self.calendar.mark_day(date[2])
    
    def checkAppt(self, *args):
        date = self.calendar.get_date()
        for j in self.root.iter('appt'):
            dateTup = self.dateObj2Tuple(j[0])
            if dateTup == date:
                self.buffer.set_text(j[1].text)
                break
            else:
                self.buffer.set_text('')
        
    def saveAppt(self, *args):
        date = self.calendar.get_date()
        
        start = self.buffer.get_start_iter()
        end = self.buffer.get_end_iter()
        detail = self.buffer.get_text(start,end,True)
        
        for j in self.root.iter('appt'):
            dateTup = self.dateObj2Tuple(j[0])
            if dateTup == date:
                self.root.remove(j)

        if detail != "":
            newAppt = ET.SubElement(self.root,'appt')
            newDate = ET.SubElement(newAppt, 'date')
            Year = ET.SubElement(newDate, 'year')
            Month = ET.SubElement(newDate, 'month')
            Day = ET.SubElement(newDate, 'day')
			
            Year.text = str(date[0])
            Month.text = str(date[1])
            Day.text = str(date[2])

            newDetail = ET.SubElement(newAppt,'detail')
            newDetail.text = detail
            
            self.tree.write(self.datafile)

        self.markDays()
        
if __name__ == "__main__":
    main = calendarApp()
    Gtk.main()
